function cf = nantozerofield(f)
%NANTOZEROFIELD  Converts NaN elements to 0 in fields
%   CF = NANTOZEROFIELD(F) converts all the Nan elements of the vector/scalar
%   field array F into 0s.
%
%   See also  ZEROTONANFIELD, INTERPF.

%   F. Moisy, moisy_at_fast.u-psud.fr
%   Revision: 1.00,  Date: 2008/10/08
%   This function is part of the PIVMat Toolbox



% History:
% 2008/10/08: v1.00, first version.


cf = f;

for i=1:numel(f)
    if isfield(f(i),'vx')
        cf(i).vx(isnan(f(i).vx)) = 0;
        cf(i).vy(isnan(f(i).vy)) = 0;
    else
        cf(i).w(isnan(f(i).w)) = 0;
    end
end
